package info.aspirecn.cloud.yysj.controller;

import java.util.Map;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RestController;

import info.aspirecn.cloud.yysj.entity.ResponseInfo;
import info.aspirecn.cloud.yysj.entity.request.DriverDetailsRequest;
import info.aspirecn.cloud.yysj.entity.request.DriverInfoRequest;
import info.aspirecn.cloud.yysj.entity.response.DriverInfoDetailsResponse;
import info.aspirecn.cloud.yysj.service.DriverService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;

/**
 * 司机列表、司机详情等信息查询
 *
 * @author baizehui
 */
@Api(tags = "司机查询相关服务接口")
@ApiResponses({
        @ApiResponse(code = 200, message = "成功处理请求"),
        @ApiResponse(code = 400, message = "参数错误"),
        @ApiResponse(code = 401, message = "没有权限访问该服务"),
        @ApiResponse(code = 403, message = "权限不足无法访问该服务"),
        @ApiResponse(code = 404, message = "未发现该微服务"),
        @ApiResponse(code = 500, message = "服务器内部错误")
})
@RestController
@Slf4j
public class DriverController {
	
	@Autowired
    private DriverService driverService;

    @ApiOperation(value = "查询司机校验信息列表接口", notes = "获取司机校验信息列表接口。")
    @PostMapping("/getDriverList")
    private ResponseInfo getDriverList(@RequestHeader(required = false) String userId,@RequestBody DriverInfoRequest  driverInfoRequest, HttpServletResponse response){
        try {
        	if (userId== null&&"".equals(userId)) {
        		return new ResponseInfo().setMessage("userId不能为空");
        	}
        	Map<String, Object> map =driverService.getDriverList(userId,driverInfoRequest);
        	 Integer total = (Integer)map.get("total");
            response.addHeader("pageNum", Integer.toString(driverInfoRequest.getPageNum()));
            response.addHeader("pageSize", Integer.toString(driverInfoRequest.getPageSize()));
            response.addHeader("pageTotal",   Integer.toString(total%driverInfoRequest.getPageSize() > 0 ? total/driverInfoRequest.getPageSize()+1 : total/driverInfoRequest.getPageSize()));
            response.addHeader("total",Integer.toString(total));
            return new ResponseInfo().setData(map.get("dataList"));
        } catch (Exception e) {
            log.error("查询司机校验信息列表接口,e:{}", e);
        }
		return null;
    	
    }
    
    @ApiOperation(value = "查询司机详情信息接口", notes = "获取司机详情信息接口。")
    @PostMapping("/getDriverDetails")
    private ResponseInfo getDriverDetails(@RequestHeader(required = false) String userId,
    		@RequestBody DriverDetailsRequest driverDetailsRequest){
        
        try {
        	if (userId== null&&"".equals(userId)) {
        		return new ResponseInfo().setMessage("userId不能为空");
        	}
        	if (driverDetailsRequest.getDriverName()== null&&"".equals(driverDetailsRequest.getDriverName())) {
        		return new ResponseInfo().setMessage("driverName不能为空");
        	}
        	if (driverDetailsRequest.getDrivingLicense()== null&&"".equals(driverDetailsRequest.getDrivingLicense())) {
        		return new ResponseInfo().setMessage("drivingLicense不能为空");
        	}
         	DriverInfoDetailsResponse driverInfoDetails=driverService.getDriverDetails(userId,driverDetailsRequest.getDriverName(),driverDetailsRequest.getDrivingLicense());
            return new ResponseInfo().setData(driverInfoDetails);
        } catch (Exception e) {
            log.error("查询司机详情信息列表接口,e:{}", e);
        }
		return null;
    }
}
