package info.aspirecn.cloud.yysj.utils;

import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.extern.slf4j.Slf4j;
import org.elasticsearch.action.search.SearchRequest;
import org.elasticsearch.action.search.SearchResponse;
import org.elasticsearch.client.RequestOptions;
import org.elasticsearch.client.RestHighLevelClient;
import org.elasticsearch.rest.RestStatus;
import org.elasticsearch.search.SearchHit;
import org.elasticsearch.search.SearchHits;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

@Slf4j
@Component
public class ElasticSearchUitls {

    @Autowired
    private RestHighLevelClient restHighLevelClient;

    @Autowired
    private ObjectMapper objectMapper;

    /**
             * 获取查询结果
     *
     * @param searchRequest 查询请求对象
     * @return 结果数据集合
     */
    public <T> List<T> getResult(SearchRequest searchRequest, Class<T> type) {
        // 设置返回集合
        List<T> list = new ArrayList<>();
        // 使用 RestHighLevelClient 客户端进行请求
        try {
            SearchResponse searchResponse = restHighLevelClient.search(searchRequest, RequestOptions.DEFAULT);
            // 根据状态和数据条数验证是否返回了数据
            if (RestStatus.OK.equals(searchResponse.status()) && searchResponse.getHits().totalHits > 0) {
                SearchHits hits = searchResponse.getHits();
                for (SearchHit hit : hits) {
                    // 将 JSON 转换成对象
                    T t = objectMapper.readValue(hit.getSourceAsString(), type);
                    // 加入到对象集合
                    list.add(t);
                }
            }
        } catch (IOException e) {
            log.error("", e);
        }
        return list;
    }
    
    
	/**
	 * 获取查询结果
	 *
	 * @param searchRequest 查询请求对象
	 * @return 
	 * @return 结果数据集合
	 */
	public  SearchHits getResultHits(SearchRequest searchRequest) {
		// 使用 RestHighLevelClient 客户端进行请求
		try {
			SearchResponse searchResponse = restHighLevelClient.search(searchRequest, RequestOptions.DEFAULT);
			// 根据状态和数据条数验证是否返回了数据
			if (RestStatus.OK.equals(searchResponse.status()) && searchResponse.getHits().totalHits > 0) {
				SearchHits hits = searchResponse.getHits();
				return hits;
			}
		} catch (IOException e) {
			log.error("", e);
		}
		return null;
	}

}
